##

##

##

    		@ Private Addresses
    		@ Key Addresses

    		#
    		#	Knights
    		#
    		#	Operations
    		#
    		#	@ Attendants
    		#
    		#	Chaperones
    		#	Parent or Guardian Necessary
    		#
    		#	@ Bosses
    		#	@ Besties
    		#	@ Authorized Organisms
    		#	@ Business Zone
    		#	@ Badge Required
    		#	@ Restricted
    		#	@ Private
    		#	@ Prestigious
    		#	@ Off Limits
    		#	@ Key
    		#	@ Collaborators
    		#
    		#	Staff
    		#		@ Technicians
    		#		@ Colleagues
    		#		@ Team @ League
    		#		@ Representatives
    		#		@ Contributors
    		#		@ Squad
    		#		@ Tribe
    		#		@ Council
    		#		@ Trustees
    		#		@ Allies
    		#

    	objectives -- dreams

    		[ ] These should require a key.

    	objectives

    	important
    		https://sanic.dev/en/plugins/sanic-ext/openapi/security.html#openapi

    		https://swagger.io/specification/